@@ -63,7 +63,7 @@ format_vehicles = function(x) {
 }
 
 format_stats19 = function(x, type) {
-  # rename colums
+  # Rename columns
   old_names = names(x)
   new_names = format_column_names(old_names)
   names(x) = new_names
@@ -81,7 +81,12 @@ format_stats19 = function(x, type) {
       stats19::stats19_schema$variable_formatted == lkp_name,
       c("code", "label")
       ]
-    x[[i]] = lookup$label[match(x[[i]], lookup$code)]
+    original_class = class(x[[i]])
+    # Use lookup to replace codes with labels, but keep original values for non-matches
+    # See https://github.com/ropensci/stats19/issues/235#issuecomment-2254257770
+    matched_labels = lookup$label[match(x[[i]], lookup$code)]
+    x[[i]] = ifelse(is.na(matched_labels), x[[i]], matched_labels)
+    x[[i]] = methods::as(x[[i]], original_class)
   }
 
   date_in_names = "date" %in% names(x)
@@ -111,6 +116,7 @@ format_stats19 = function(x, type) {
   x
 }
 
+
 #' Format column names of raw STATS19 data
 #'
 #' This function takes messy column names and returns clean ones that work well with
